<?php

namespace Superrobota\FD\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Superrobota\FD\Http\Requests\FDRequest;
use Superrobota\FD\Interfaces\FDRepositoryInterface;
use Superrobota\FD\Models\FD;

/**
 * Resource controller class for f_d.
 */
class FDResourceController extends BaseController
{

    /**
     * Initialize f_d resource controller.
     *
     * @param type FDRepositoryInterface $f_d
     *
     * @return null
     */
    public function __construct(FDRepositoryInterface $f_d)
    {
        parent::__construct();
        $this->repository = $f_d;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Superrobota\FD\Repositories\Criteria\FDResourceCriteria::class);
    }

    /**
     * Display a list of f_d.
     *
     * @return Response
     */
    public function index(FDRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Superrobota\FD\Repositories\Presenter\FDPresenter::class)
                ->$function();
        }

        $f_d_s = $this->repository->paginate();

        return $this->response->title(trans('f_d::f_d.names'))
            ->view('f_d::f_d.index', true)
            ->data(compact('f_d_s'))
            ->output();
    }

    /**
     * Display f_d.
     *
     * @param Request $request
     * @param Model   $f_d
     *
     * @return Response
     */
    public function show(FDRequest $request, FD $f_d)
    {

        if ($f_d->exists) {
            $view = 'f_d::f_d.show';
        } else {
            $view = 'f_d::f_d.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('f_d::f_d.name'))
            ->data(compact('f_d'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new f_d.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(FDRequest $request)
    {

        $f_d = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('f_d::f_d.name')) 
            ->view('f_d::f_d.create', true) 
            ->data(compact('f_d'))
            ->output();
    }

    /**
     * Create new f_d.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(FDRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $f_d                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('f_d::f_d.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('f_d/f_d/' . $f_d->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/f_d/f_d'))
                ->redirect();
        }

    }

    /**
     * Show f_d for editing.
     *
     * @param Request $request
     * @param Model   $f_d
     *
     * @return Response
     */
    public function edit(FDRequest $request, FD $f_d)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('f_d::f_d.name'))
            ->view('f_d::f_d.edit', true)
            ->data(compact('f_d'))
            ->output();
    }

    /**
     * Update the f_d.
     *
     * @param Request $request
     * @param Model   $f_d
     *
     * @return Response
     */
    public function update(FDRequest $request, FD $f_d)
    {
        try {
            $attributes = $request->all();

            $f_d->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('f_d::f_d.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('f_d/f_d/' . $f_d->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('f_d/f_d/' . $f_d->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the f_d.
     *
     * @param Model   $f_d
     *
     * @return Response
     */
    public function destroy(FDRequest $request, FD $f_d)
    {
        try {

            $f_d->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('f_d::f_d.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('f_d/f_d/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('f_d/f_d/' . $f_d->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple f_d.
     *
     * @param Model   $f_d
     *
     * @return Response
     */
    public function delete(FDRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('f_d::f_d.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('f_d/f_d'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/f_d/f_d'))
                ->redirect();
        }

    }

    /**
     * Restore deleted f_d_s.
     *
     * @param Model   $f_d
     *
     * @return Response
     */
    public function restore(FDRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('f_d::f_d.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/f_d/f_d'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/f_d/f_d/'))
                ->redirect();
        }

    }

}
