<?php

namespace Superrobota\FD\Policies;

use Litepie\User\Contracts\UserPolicy;
use Superrobota\FD\Models\FD;

class FDPolicy
{

    /**
     * Determine if the given user can view the f_d.
     *
     * @param UserPolicy $user
     * @param FD $f_d
     *
     * @return bool
     */
    public function view(UserPolicy $user, FD $f_d)
    {
        if ($user->canDo('f_d.f_d.view') && $user->isAdmin()) {
            return true;
        }

        return $f_d->user_id == user_id() && $f_d->user_type == user_type();
    }

    /**
     * Determine if the given user can create a f_d.
     *
     * @param UserPolicy $user
     * @param FD $f_d
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('f_d.f_d.create');
    }

    /**
     * Determine if the given user can update the given f_d.
     *
     * @param UserPolicy $user
     * @param FD $f_d
     *
     * @return bool
     */
    public function update(UserPolicy $user, FD $f_d)
    {
        if ($user->canDo('f_d.f_d.edit') && $user->isAdmin()) {
            return true;
        }

        return $f_d->user_id == user_id() && $f_d->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given f_d.
     *
     * @param UserPolicy $user
     * @param FD $f_d
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, FD $f_d)
    {
        return $f_d->user_id == user_id() && $f_d->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given f_d.
     *
     * @param UserPolicy $user
     * @param FD $f_d
     *
     * @return bool
     */
    public function verify(UserPolicy $user, FD $f_d)
    {
        if ($user->canDo('f_d.f_d.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given f_d.
     *
     * @param UserPolicy $user
     * @param FD $f_d
     *
     * @return bool
     */
    public function approve(UserPolicy $user, FD $f_d)
    {
        if ($user->canDo('f_d.f_d.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
