<?php

namespace Superrobota\FD\Providers;

use Illuminate\Support\ServiceProvider;

class FDServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'f_d');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'f_d');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('superrobota.f_d', function ($app) {
            return $this->app->make('Superrobota\FD\FD');
        });

                // Bind FD to repository
        $this->app->bind(
            'Superrobota\FD\Interfaces\FDRepositoryInterface',
            \Superrobota\FD\Repositories\Eloquent\FDRepository::class
        );

        $this->app->register(\Superrobota\FD\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Superrobota\FD\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['superrobota.f_d'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('superrobota/f_d.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/f_d')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/f_d')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
